@@ -33,4 +33,4 @@ templates = (
   ('N4BiasFieldCorrectionImageFilter', 'itk::N4BiasFieldCorrectionImageFilter', 'itkN4BiasFieldCorrectionImageFilterIF2IUC2IF2', True, 'itk::Image< float,2 >, itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
   ('N4BiasFieldCorrectionImageFilter', 'itk::N4BiasFieldCorrectionImageFilter', 'itkN4BiasFieldCorrectionImageFilterIF3IUC3IF3', True, 'itk::Image< float,3 >, itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
 )
-snake_case_functions = ('n4_bias_field_correction_image_filter', 'image_to_image_filter', )
+snake_case_functions = ('image_to_image_filter', 'n4_bias_field_correction_image_filter', )
