@@ -63,4 +63,4 @@ templates = (
   ('ErodeObjectMorphologyImageFilter', 'itk::ErodeObjectMorphologyImageFilter', 'itkErodeObjectMorphologyImageFilterIUS3IUS3SE3', True, 'itk::Image< unsigned short,3 >,itk::Image< unsigned short,3 >,itk::FlatStructuringElement< 3 >'),
   ('ErodeObjectMorphologyImageFilter', 'itk::ErodeObjectMorphologyImageFilter', 'itkErodeObjectMorphologyImageFilterIF3IF3SE3', True, 'itk::Image< float,3 >,itk::Image< float,3 >,itk::FlatStructuringElement< 3 >'),
 )
-snake_case_functions = ('binary_dilate_image_filter', 'object_morphology_image_filter', 'erode_object_morphology_image_filter', 'dilate_object_morphology_image_filter', 'binary_opening_by_reconstruction_image_filter', 'binary_pruning_image_filter', 'binary_closing_by_reconstruction_image_filter', 'binary_morphological_opening_image_filter', 'binary_thinning_image_filter', 'binary_morphological_closing_image_filter', 'binary_morphology_image_filter', 'binary_erode_image_filter', )
+snake_case_functions = ('binary_morphology_image_filter', 'erode_object_morphology_image_filter', 'binary_thinning_image_filter', 'binary_closing_by_reconstruction_image_filter', 'binary_erode_image_filter', 'dilate_object_morphology_image_filter', 'binary_morphological_opening_image_filter', 'object_morphology_image_filter', 'binary_dilate_image_filter', 'binary_opening_by_reconstruction_image_filter', 'binary_pruning_image_filter', 'binary_morphological_closing_image_filter', )
