@@ -145,4 +145,4 @@ templates = (
   ('VectorConnectedComponentImageFilter', 'itk::VectorConnectedComponentImageFilter', 'itkVectorConnectedComponentImageFilterICVF42IUS2', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< unsigned short,2 >'),
   ('VectorConnectedComponentImageFilter', 'itk::VectorConnectedComponentImageFilter', 'itkVectorConnectedComponentImageFilterICVF43IUS3', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< unsigned short,3 >'),
 )
-snake_case_functions = ('scalar_connected_component_image_filter', 'connected_component_functor_image_filter', 'vector_connected_component_image_filter', 'connected_component_image_filter', 'relabel_component_image_filter', 'hard_connected_component_image_filter', 'threshold_maximum_connected_components_image_filter', )
+snake_case_functions = ('connected_component_functor_image_filter', 'scalar_connected_component_image_filter', 'relabel_component_image_filter', 'connected_component_image_filter', 'threshold_maximum_connected_components_image_filter', 'vector_connected_component_image_filter', 'hard_connected_component_image_filter', )
