@@ -41,4 +41,4 @@ templates = (
   ('MaskedFFTNormalizedCorrelationImageFilter', 'itk::MaskedFFTNormalizedCorrelationImageFilter', 'itkMaskedFFTNormalizedCorrelationImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
   ('MaskedFFTNormalizedCorrelationImageFilter', 'itk::MaskedFFTNormalizedCorrelationImageFilter', 'itkMaskedFFTNormalizedCorrelationImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
 )
-snake_case_functions = ('fft_normalized_correlation_image_filter', 'masked_fft_normalized_correlation_image_filter', 'convolution_image_filter', 'fft_convolution_image_filter', 'convolution_image_filter_base', )
+snake_case_functions = ('fft_convolution_image_filter', 'fft_normalized_correlation_image_filter', 'masked_fft_normalized_correlation_image_filter', 'convolution_image_filter_base', 'convolution_image_filter', )
