@@ -57,4 +57,4 @@ templates = (
   ('WienerDeconvolutionImageFilter', 'itk::WienerDeconvolutionImageFilter', 'itkWienerDeconvolutionImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
   ('WienerDeconvolutionImageFilter', 'itk::WienerDeconvolutionImageFilter', 'itkWienerDeconvolutionImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
 )
-snake_case_functions = ('tikhonov_deconvolution_image_filter', 'projected_landweber_deconvolution_image_filter', 'richardson_lucy_deconvolution_image_filter', 'wiener_deconvolution_image_filter', 'inverse_deconvolution_image_filter', 'landweber_deconvolution_image_filter', 'projected_iterative_deconvolution_image_filter', 'iterative_deconvolution_image_filter', )
+snake_case_functions = ('landweber_deconvolution_image_filter', 'richardson_lucy_deconvolution_image_filter', 'inverse_deconvolution_image_filter', 'tikhonov_deconvolution_image_filter', 'wiener_deconvolution_image_filter', 'iterative_deconvolution_image_filter', 'projected_iterative_deconvolution_image_filter', 'projected_landweber_deconvolution_image_filter', )
