@@ -71,4 +71,4 @@ templates = (
   ('SignedMaurerDistanceMapImageFilter', 'itk::SignedMaurerDistanceMapImageFilter', 'itkSignedMaurerDistanceMapImageFilterIUS2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
   ('SignedMaurerDistanceMapImageFilter', 'itk::SignedMaurerDistanceMapImageFilter', 'itkSignedMaurerDistanceMapImageFilterIUS3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
 )
-snake_case_functions = ('signed_danielsson_distance_map_image_filter', 'approximate_signed_distance_map_image_filter', 'fast_chamfer_distance_image_filter', 'hausdorff_distance_image_filter', 'signed_maurer_distance_map_image_filter', 'directed_hausdorff_distance_image_filter', 'danielsson_distance_map_image_filter', 'contour_directed_mean_distance_image_filter', 'contour_mean_distance_image_filter', 'iso_contour_distance_image_filter', )
+snake_case_functions = ('contour_directed_mean_distance_image_filter', 'contour_mean_distance_image_filter', 'directed_hausdorff_distance_image_filter', 'danielsson_distance_map_image_filter', 'iso_contour_distance_image_filter', 'signed_danielsson_distance_map_image_filter', 'signed_maurer_distance_map_image_filter', 'hausdorff_distance_image_filter', 'fast_chamfer_distance_image_filter', 'approximate_signed_distance_map_image_filter', )
