@@ -77,4 +77,4 @@ templates = (
   ('VnlRealToHalfHermitianForwardFFTImageFilter', 'itk::VnlRealToHalfHermitianForwardFFTImageFilter', 'itkVnlRealToHalfHermitianForwardFFTImageFilterIF2ICF2', True, 'itk::Image< float,2 >, itk::Image< std::complex< float >,2 >'),
   ('VnlRealToHalfHermitianForwardFFTImageFilter', 'itk::VnlRealToHalfHermitianForwardFFTImageFilter', 'itkVnlRealToHalfHermitianForwardFFTImageFilterIF3ICF3', True, 'itk::Image< float,3 >, itk::Image< std::complex< float >,3 >'),
 )
-snake_case_functions = ('full_to_half_hermitian_image_filter', 'vnl_forward_fft_image_filter', 'vnl_half_hermitian_to_real_inverse_fft_image_filter', 'inverse_fft_image_filter', 'fft_shift_image_filter', 'real_to_half_hermitian_forward_fft_image_filter', 'forward_fft_image_filter', 'vnl_real_to_half_hermitian_forward_fft_image_filter', 'complex_to_complex_fft_image_filter', 'fft_pad_image_filter', 'half_to_full_hermitian_image_filter', 'vnl_complex_to_complex_fft_image_filter', 'vnl_inverse_fft_image_filter', 'half_hermitian_to_real_inverse_fft_image_filter', )
+snake_case_functions = ('inverse_fft_image_filter', 'real_to_half_hermitian_forward_fft_image_filter', 'forward_fft_image_filter', 'fft_pad_image_filter', 'half_hermitian_to_real_inverse_fft_image_filter', 'half_to_full_hermitian_image_filter', 'vnl_forward_fft_image_filter', 'vnl_inverse_fft_image_filter', 'vnl_half_hermitian_to_real_inverse_fft_image_filter', 'full_to_half_hermitian_image_filter', 'complex_to_complex_fft_image_filter', 'fft_shift_image_filter', 'vnl_complex_to_complex_fft_image_filter', 'vnl_real_to_half_hermitian_forward_fft_image_filter', )
