@@ -53,4 +53,4 @@ templates = (
   ('FastMarchingUpwindGradientImageFilterBase', 'itk::FastMarchingUpwindGradientImageFilterBase', 'itkFastMarchingUpwindGradientImageFilterBaseIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
   ('FastMarchingUpwindGradientImageFilterBase', 'itk::FastMarchingUpwindGradientImageFilterBase', 'itkFastMarchingUpwindGradientImageFilterBaseIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
 )
-snake_case_functions = ('fast_marching_image_filter_base', 'fast_marching_base', 'fast_marching_image_filter', 'fast_marching_upwind_gradient_image_filter_base', 'fast_marching_upwind_gradient_image_filter', 'fast_marching_extension_image_filter', )
+snake_case_functions = ('fast_marching_upwind_gradient_image_filter', 'fast_marching_upwind_gradient_image_filter_base', 'fast_marching_image_filter_base', 'fast_marching_base', 'fast_marching_image_filter', 'fast_marching_extension_image_filter', )
