@@ -133,4 +133,4 @@ templates = (
   ('ImageSeriesWriter', 'itk::ImageSeriesWriter', 'itkImageSeriesWriterIRGBUC3IRGBUC2', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >,itk::Image< itk::RGBPixel< unsigned char >,2 >'),
   ('ImageSeriesWriter', 'itk::ImageSeriesWriter', 'itkImageSeriesWriterICF3ICF2', True, 'itk::Image< std::complex< float >,3 >,itk::Image< std::complex< float >,2 >'),
 )
-snake_case_functions = ('image_file_reader', 'image_file_writer', 'image_series_reader', 'image_series_writer', )
+snake_case_functions = ('image_series_writer', 'image_series_reader', 'image_file_writer', 'image_file_reader', )
