@@ -53,4 +53,4 @@ templates = (
   ('SquaredDifferenceImageFilter', 'itk::SquaredDifferenceImageFilter', 'itkSquaredDifferenceImageFilterIF2IF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >, itk::Image< float,2 >'),
   ('SquaredDifferenceImageFilter', 'itk::SquaredDifferenceImageFilter', 'itkSquaredDifferenceImageFilterIF3IF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >, itk::Image< float,3 >'),
 )
-snake_case_functions = ('squared_difference_image_filter', 'similarity_index_image_filter', 'staple_image_filter', 'absolute_value_difference_image_filter', 'checker_board_image_filter', )
+snake_case_functions = ('absolute_value_difference_image_filter', 'checker_board_image_filter', 'similarity_index_image_filter', 'staple_image_filter', 'squared_difference_image_filter', )
