@@ -103,4 +103,4 @@ templates = (
   ('ZeroCrossingImageFilter', 'itk::ZeroCrossingImageFilter', 'itkZeroCrossingImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
   ('ZeroCrossingImageFilter', 'itk::ZeroCrossingImageFilter', 'itkZeroCrossingImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
 )
-snake_case_functions = ('laplacian_image_filter', 'zero_crossing_based_edge_detection_image_filter', 'derivative_image_filter', 'canny_edge_detection_image_filter', 'mask_feature_point_selection_filter', 'hessian3_d_to_vesselness_measure_image_filter', 'multi_scale_hessian_based_measure_image_filter', 'hessian_to_objectness_measure_image_filter', 'hough_transform2_d_circles_image_filter', 'sobel_edge_detection_image_filter', 'hessian_recursive_gaussian_image_filter', 'bilateral_image_filter', 'simple_contour_extractor_image_filter', 'discrete_gaussian_derivative_image_filter', 'mesh_source', 'gradient_vector_flow_image_filter', 'laplacian_sharpening_image_filter', 'unsharp_mask_image_filter', 'image_to_mesh_filter', 'zero_crossing_image_filter', 'laplacian_recursive_gaussian_image_filter', 'hough_transform2_d_lines_image_filter', )
+snake_case_functions = ('hessian3_d_to_vesselness_measure_image_filter', 'multi_scale_hessian_based_measure_image_filter', 'zero_crossing_based_edge_detection_image_filter', 'derivative_image_filter', 'hough_transform2_d_lines_image_filter', 'simple_contour_extractor_image_filter', 'sobel_edge_detection_image_filter', 'image_to_mesh_filter', 'canny_edge_detection_image_filter', 'hessian_to_objectness_measure_image_filter', 'hessian_recursive_gaussian_image_filter', 'laplacian_image_filter', 'mask_feature_point_selection_filter', 'bilateral_image_filter', 'laplacian_recursive_gaussian_image_filter', 'hough_transform2_d_circles_image_filter', 'unsharp_mask_image_filter', 'discrete_gaussian_derivative_image_filter', 'zero_crossing_image_filter', 'gradient_vector_flow_image_filter', 'mesh_source', 'laplacian_sharpening_image_filter', )
