@@ -313,4 +313,4 @@ templates = (
   ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIRGBAUC2IUC2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >, itk::Image< unsigned char,2 >'),
   ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIRGBAUC3IUC3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< unsigned char,3 >'),
 )
-snake_case_functions = ('binary_generator_image_filter', 'cast_image_filter', 'recursive_separable_image_filter', 'box_image_filter', 'unary_generator_image_filter', 'noise_image_filter', 'in_place_image_filter', )
+snake_case_functions = ('recursive_separable_image_filter', 'in_place_image_filter', 'cast_image_filter', 'box_image_filter', 'unary_generator_image_filter', 'binary_generator_image_filter', 'noise_image_filter', )
