@@ -23,4 +23,4 @@ templates = (
   ('LabelToRGBImageFilter', 'itk::LabelToRGBImageFilter', 'itkLabelToRGBImageFilterIUL2IRGBUC2', True, 'itk::Image< unsigned long,2 >, itk::Image< itk::RGBPixel< unsigned char >,2 >'),
   ('LabelToRGBImageFilter', 'itk::LabelToRGBImageFilter', 'itkLabelToRGBImageFilterIUL3IRGBUC3', True, 'itk::Image< unsigned long,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
 )
-snake_case_functions = ('label_map_to_rgb_image_filter', 'unary_functor_image_filter', 'label_overlay_image_filter', 'label_to_rgb_image_filter', 'label_map_contour_overlay_image_filter', 'label_map_overlay_image_filter', )
+snake_case_functions = ('label_map_to_rgb_image_filter', 'label_overlay_image_filter', 'label_map_contour_overlay_image_filter', 'unary_functor_image_filter', 'label_to_rgb_image_filter', 'label_map_overlay_image_filter', )
