@@ -45,4 +45,4 @@ templates = (
   ('VectorGradientMagnitudeImageFilter', 'itk::VectorGradientMagnitudeImageFilter', 'itkVectorGradientMagnitudeImageFilterIVF22F', True, 'itk::Image< itk::Vector< float,2 >,2 >, float'),
   ('VectorGradientMagnitudeImageFilter', 'itk::VectorGradientMagnitudeImageFilter', 'itkVectorGradientMagnitudeImageFilterIVF33F', True, 'itk::Image< itk::Vector< float,3 >,3 >, float'),
 )
-snake_case_functions = ('gradient_recursive_gaussian_image_filter', 'difference_of_gaussians_gradient_image_filter', 'gradient_image_filter', 'vector_gradient_magnitude_image_filter', 'gradient_magnitude_recursive_gaussian_image_filter', 'gradient_magnitude_image_filter', )
+snake_case_functions = ('gradient_magnitude_image_filter', 'vector_gradient_magnitude_image_filter', 'gradient_recursive_gaussian_image_filter', 'difference_of_gaussians_gradient_image_filter', 'gradient_magnitude_recursive_gaussian_image_filter', 'gradient_image_filter', )
