@@ -85,4 +85,4 @@ templates = (
   ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF42IUS2', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< unsigned short,2 >'),
   ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF43IUS3', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< unsigned short,3 >'),
 )
-snake_case_functions = ('unary_functor_image_filter', 'label_contour_image_filter', 'binary_contour_image_filter', 'change_label_image_filter', )
+snake_case_functions = ('label_contour_image_filter', 'change_label_image_filter', 'binary_contour_image_filter', 'unary_functor_image_filter', )
