@@ -41,4 +41,4 @@ templates = (
   ('SpeckleNoiseImageFilter', 'itk::SpeckleNoiseImageFilter', 'itkSpeckleNoiseImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
   ('SpeckleNoiseImageFilter', 'itk::SpeckleNoiseImageFilter', 'itkSpeckleNoiseImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
 )
-snake_case_functions = ('noise_base_image_filter', 'shot_noise_image_filter', 'additive_gaussian_noise_image_filter', 'speckle_noise_image_filter', 'salt_and_pepper_noise_image_filter', )
+snake_case_functions = ('speckle_noise_image_filter', 'salt_and_pepper_noise_image_filter', 'noise_base_image_filter', 'shot_noise_image_filter', 'additive_gaussian_noise_image_filter', )
