@@ -113,4 +113,4 @@ templates = (
   ('PhysicalPointImageSource', 'itk::PhysicalPointImageSource', 'itkPhysicalPointImageSourceVIUS3', True, 'itk::VectorImage< unsigned short,3 >'),
   ('PhysicalPointImageSource', 'itk::PhysicalPointImageSource', 'itkPhysicalPointImageSourceVIF3', True, 'itk::VectorImage< float,3 >'),
 )
-snake_case_functions = ('grid_image_source', 'generate_image_source', 'gabor_image_source', 'gaussian_image_source', 'physical_point_image_source', 'parametric_image_source', )
+snake_case_functions = ('gabor_image_source', 'gaussian_image_source', 'parametric_image_source', 'physical_point_image_source', 'grid_image_source', 'generate_image_source', )
