@@ -192,4 +192,4 @@ templates = (
   ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterIUS3IUS2', True, 'itk::Image< unsigned short,3 >,itk::Image< unsigned short,2 >'),
   ('SumProjectionImageFilter', 'itk::SumProjectionImageFilter', 'itkSumProjectionImageFilterIF3IF2', True, 'itk::Image< float,3 >,itk::Image< float,2 >'),
 )
-snake_case_functions = ('binary_projection_image_filter', 'minimum_projection_image_filter', 'mean_projection_image_filter', 'standard_deviation_projection_image_filter', 'adaptive_histogram_equalization_image_filter', 'maximum_projection_image_filter', 'label_statistics_image_filter', 'sum_projection_image_filter', 'accumulate_image_filter', 'moving_histogram_image_filter_base', 'minimum_maximum_image_filter', 'image_shape_model_estimator_base', 'statistics_image_filter', 'kernel_image_filter', 'projection_image_filter', 'image_pca_shape_model_estimator', 'median_projection_image_filter', 'moving_histogram_image_filter', )
+snake_case_functions = ('image_pca_shape_model_estimator', 'label_statistics_image_filter', 'maximum_projection_image_filter', 'mean_projection_image_filter', 'statistics_image_filter', 'binary_projection_image_filter', 'kernel_image_filter', 'standard_deviation_projection_image_filter', 'moving_histogram_image_filter', 'median_projection_image_filter', 'projection_image_filter', 'sum_projection_image_filter', 'minimum_maximum_image_filter', 'minimum_projection_image_filter', 'image_shape_model_estimator_base', 'accumulate_image_filter', 'moving_histogram_image_filter_base', 'adaptive_histogram_equalization_image_filter', )
