@@ -189,9 +189,13 @@ templates = (
   ('BinaryMask3DMeshSource', 'itk::BinaryMask3DMeshSource', 'itkBinaryMask3DMeshSourceIUS3MUS3', True, 'itk::Image< unsigned short,3 >, itk::Mesh< unsigned short,3 >'),
   ('BinaryMask3DMeshSource', 'itk::BinaryMask3DMeshSource', 'itkBinaryMask3DMeshSourceIUS3MF3', True, 'itk::Image< unsigned short,3 >, itk::Mesh< float,3 >'),
   ('BinaryMask3DMeshSource', 'itk::BinaryMask3DMeshSource', 'itkBinaryMask3DMeshSourceIUS3MD3', True, 'itk::Image< unsigned short,3 >, itk::Mesh< double,3 >'),
+  ('TransformMeshFilter', 'itk::TransformMeshFilter', 'itkTransformMeshFilterMF2MF2TD22', True, 'itk::Mesh< float,2 >, itk::Mesh< float,2 >, itk::Transform< double, 2, 2 >'),
+  ('TransformMeshFilter', 'itk::TransformMeshFilter', 'itkTransformMeshFilterMF2MF2TF22', True, 'itk::Mesh< float,2 >, itk::Mesh< float,2 >, itk::Transform< float, 2, 2 >'),
+  ('TransformMeshFilter', 'itk::TransformMeshFilter', 'itkTransformMeshFilterMF3MF3TD33', True, 'itk::Mesh< float,3 >, itk::Mesh< float,3 >, itk::Transform< double, 3, 3 >'),
+  ('TransformMeshFilter', 'itk::TransformMeshFilter', 'itkTransformMeshFilterMF3MF3TF33', True, 'itk::Mesh< float,3 >, itk::Mesh< float,3 >, itk::Transform< float, 3, 3 >'),
   ('Point1D', 'itk::Point1D', 'itkPoint1D', False),
   ('TriangleMeshToBinaryImageFilter', 'itk::TriangleMeshToBinaryImageFilter', 'itkTriangleMeshToBinaryImageFilterMSS3ISS3', True, 'itk::Mesh< signed short,3 >, itk::Image< signed short,3 > '),
   ('TriangleMeshToBinaryImageFilter', 'itk::TriangleMeshToBinaryImageFilter', 'itkTriangleMeshToBinaryImageFilterMUC3IUC3', True, 'itk::Mesh< unsigned char,3 >, itk::Image< unsigned char,3 > '),
   ('TriangleMeshToBinaryImageFilter', 'itk::TriangleMeshToBinaryImageFilter', 'itkTriangleMeshToBinaryImageFilterMUS3IUS3', True, 'itk::Mesh< unsigned short,3 >, itk::Image< unsigned short,3 > '),
 )
-snake_case_functions = ('mesh_source', 'mesh_to_mesh_filter', 'vtk_poly_data_reader', 'image_to_mesh_filter', 'triangle_mesh_to_binary_image_filter', 'binary_mask3_d_mesh_source', )
+snake_case_functions = ('image_to_mesh_filter', 'mesh_to_mesh_filter', 'transform_mesh_filter', 'triangle_mesh_to_binary_image_filter', 'mesh_source', 'vtk_poly_data_reader', 'binary_mask3_d_mesh_source', )
