@@ -99,4 +99,4 @@ templates = (
   ('SymmetricForcesDemonsRegistrationFilter', 'itk::SymmetricForcesDemonsRegistrationFilter', 'itkSymmetricForcesDemonsRegistrationFilterIF2IF2IVF42', True, 'itk::Image< float,2 >, itk::Image< float,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
   ('SymmetricForcesDemonsRegistrationFilter', 'itk::SymmetricForcesDemonsRegistrationFilter', 'itkSymmetricForcesDemonsRegistrationFilterIF3IF3IVF43', True, 'itk::Image< float,3 >, itk::Image< float,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
 )
-snake_case_functions = ('multi_resolution_pde_deformable_registration', 'level_set_motion_registration_filter', 'pde_deformable_registration_filter', 'demons_registration_filter', 'symmetric_forces_demons_registration_filter', )
+snake_case_functions = ('level_set_motion_registration_filter', 'multi_resolution_pde_deformable_registration', 'pde_deformable_registration_filter', 'symmetric_forces_demons_registration_filter', 'demons_registration_filter', )
