@@ -29,4 +29,4 @@ templates = (
   ('PathSource', 'itk::PathSource', 'itkPathSourcePLPP2', True, 'itk::PolyLineParametricPath< 2 >'),
   ('PathSource', 'itk::PathSource', 'itkPathSourcePLPP3', True, 'itk::PolyLineParametricPath< 3 >'),
 )
-snake_case_functions = ('contour_extractor2_d_image_filter', 'path_to_image_filter', 'image_to_path_filter', 'path_source', )
+snake_case_functions = ('contour_extractor2_d_image_filter', 'image_to_path_filter', 'path_source', 'path_to_image_filter', )
