@@ -40,4 +40,4 @@ templates = (
   ('QuadEdgeMeshToQuadEdgeMeshFilter', 'itk::QuadEdgeMeshToQuadEdgeMeshFilter', 'itkQuadEdgeMeshToQuadEdgeMeshFilterQEMD2QEMD2', True, 'itk::QuadEdgeMesh< double,2 >, itk::QuadEdgeMesh< double,2 >'),
   ('QuadEdgeMeshToQuadEdgeMeshFilter', 'itk::QuadEdgeMeshToQuadEdgeMeshFilter', 'itkQuadEdgeMeshToQuadEdgeMeshFilterQEMD3QEMD3', True, 'itk::QuadEdgeMesh< double,3 >, itk::QuadEdgeMesh< double,3 >'),
 )
-snake_case_functions = ('mesh_source', 'quad_edge_mesh_to_quad_edge_mesh_filter', 'mesh_to_mesh_filter', 'image_to_mesh_filter', )
+snake_case_functions = ('quad_edge_mesh_to_quad_edge_mesh_filter', 'mesh_to_mesh_filter', 'image_to_mesh_filter', 'mesh_source', )
