@@ -128,4 +128,4 @@ templates = (
   ('TransformParametersAdaptorBase', 'itk::TransformParametersAdaptorBase', 'itkTransformParametersAdaptorBaseF3', True, 'itk::Transform< float,3,3 >'),
   ('TransformParametersAdaptorBase', 'itk::TransformParametersAdaptorBase', 'itkTransformParametersAdaptorBaseD3', True, 'itk::Transform< double,3,3 >'),
 )
-snake_case_functions = ('image_registration_method', 'block_matching_image_filter', 'multi_resolution_pyramid_image_filter', 'multi_resolution_image_registration_method', 'mesh_source', 'mesh_to_mesh_filter', 'recursive_multi_resolution_pyramid_image_filter', )
+snake_case_functions = ('mesh_source', 'recursive_multi_resolution_pyramid_image_filter', 'block_matching_image_filter', 'image_registration_method', 'multi_resolution_pyramid_image_filter', 'multi_resolution_image_registration_method', 'mesh_to_mesh_filter', )
