@@ -49,4 +49,4 @@ templates = (
   ('SmoothingRecursiveGaussianImageFilter', 'itk::SmoothingRecursiveGaussianImageFilter', 'itkSmoothingRecursiveGaussianImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
   ('SmoothingRecursiveGaussianImageFilter', 'itk::SmoothingRecursiveGaussianImageFilter', 'itkSmoothingRecursiveGaussianImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
 )
-snake_case_functions = ('mean_image_filter', 'binomial_blur_image_filter', 'recursive_gaussian_image_filter', 'smoothing_recursive_gaussian_image_filter', 'median_image_filter', 'discrete_gaussian_image_filter', )
+snake_case_functions = ('mean_image_filter', 'recursive_gaussian_image_filter', 'binomial_blur_image_filter', 'smoothing_recursive_gaussian_image_filter', 'discrete_gaussian_image_filter', 'median_image_filter', )
