@@ -250,4 +250,4 @@ templates = (
   ('ScalarImageToTextureFeaturesFilter', 'itk::Statistics::ScalarImageToTextureFeaturesFilter', 'itkScalarImageToTextureFeaturesFilterIF2', True, 'itk::Image< float,2 >'),
   ('ScalarImageToTextureFeaturesFilter', 'itk::Statistics::ScalarImageToTextureFeaturesFilter', 'itkScalarImageToTextureFeaturesFilterIF3', True, 'itk::Image< float,3 >'),
 )
-snake_case_functions = ('histogram_to_probability_image_filter', 'histogram_to_run_length_features_filter', 'scalar_image_to_texture_features_filter', 'histogram_to_log_probability_image_filter', 'histogram_to_entropy_image_filter', 'scalar_image_to_run_length_features_filter', 'scalar_image_to_run_length_matrix_filter', 'histogram_to_texture_features_filter', 'histogram_to_image_filter', 'scalar_image_to_cooccurrence_matrix_filter', 'masked_image_to_histogram_filter', 'image_to_histogram_filter', 'histogram_to_intensity_image_filter', )
+snake_case_functions = ('masked_image_to_histogram_filter', 'histogram_to_probability_image_filter', 'histogram_to_run_length_features_filter', 'image_to_histogram_filter', 'histogram_to_log_probability_image_filter', 'scalar_image_to_cooccurrence_matrix_filter', 'scalar_image_to_run_length_features_filter', 'histogram_to_intensity_image_filter', 'scalar_image_to_run_length_matrix_filter', 'histogram_to_image_filter', 'histogram_to_texture_features_filter', 'scalar_image_to_texture_features_filter', 'histogram_to_entropy_image_filter', )
