@@ -43,4 +43,4 @@ templates = (
   ('RandomImageSource', 'itk::RandomImageSource', 'itkRandomImageSourceIF2', True, 'itk::Image< float,2 >'),
   ('RandomImageSource', 'itk::RandomImageSource', 'itkRandomImageSourceIF3', True, 'itk::Image< float,3 >'),
 )
-snake_case_functions = ('random_image_source', 'pipeline_monitor_image_filter', 'comparison_image_filter', )
+snake_case_functions = ('comparison_image_filter', 'pipeline_monitor_image_filter', 'random_image_source', )
