@@ -54,4 +54,4 @@ templates = (
   ('VTKImageImport', 'itk::VTKImageImport', 'itkVTKImageImportICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >'),
   ('VTKImageImport', 'itk::VTKImageImport', 'itkVTKImageImportICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >'),
 )
-snake_case_functions = ('vtk_image_import', 'vtk_image_export_base', 'vtk_image_export', )
+snake_case_functions = ('vtk_image_export_base', 'vtk_image_import', 'vtk_image_export', )
